@@ -1,4 +1,3 @@
-# flake8: noqa
 import functools
 import inspect
 import logging
@@ -18,10 +17,23 @@ F = TypeVar("F")
 P = ParamSpec("P")
 R = TypeVar("R")
 TBE = TypeVar(
-    "TBE", bound=Exception
+    "TBE",
+    bound=Exception,
 )  # tilo:  original code had "BaseException" here, but thats too liberal! one should not catch SystemExit, KeyboardInterrupt, etc.!
 
 
+def as_result_logged_panic_for_param_violations(
+    *exceptions: type[TBE],
+) -> Callable[[Callable[P, R]], Callable[P, Result[R, TBE]]]:
+    """
+    exceptions as result but panic for param violations
+    """
+    return as_result_logged(
+        *exceptions,
+        panic_exceptions={BeartypeCallHintParamViolation},
+    )
+
+
 def as_result_logged(
     *exceptions: type[TBE],
     panic_exceptions: set[type[BaseException]] | None = None,
@@ -41,11 +53,13 @@ def as_result_logged(
     if not exceptions or not all(
         inspect.isclass(exception)
         and issubclass(
-            exception, Exception
+            exception,
+            Exception,
         )  # tilo: Exception instead of BaseException!
         for exception in exceptions
     ):
-        raise TypeError("as_result() requires one or more exception types")
+        msg = "as_result() requires one or more exception types"
+        raise TypeError(msg)
 
     def decorator(f: Callable[P, R]) -> Callable[P, Result[R, TBE]]:
         """
@@ -63,7 +77,7 @@ def as_result_logged(
                 tb = traceback.format_exc()
                 logger.error(tb)  # noqa: TRY400
                 if type(exc) in panic_exceptions:
-                    raise exc
+                    raise
                 return Err(exc)
 
         return wrapper
@@ -71,17 +85,6 @@ def as_result_logged(
     return decorator
 
 
-def as_result_logged_panic_for_param_violations(
-    *exceptions: type[TBE],
-) -> Callable[[Callable[P, R]], Callable[P, Result[R, TBE]]]:
-    """
-    exceptions as result but panic for param violations
-    """
-    return as_result_logged(
-        *exceptions, panic_exceptions={BeartypeCallHintParamViolation}
-    )
-
-
 # tb = traceback.format_tb(exc.__traceback__) # TODO: seems to be the same as tb = traceback.format_exc()
 # ex = traceback.format_exception_only(type(exc), exc)
 # logger.error("".join(tb+ex))
