@@ -8,12 +8,17 @@ from misc_python_utils.processing_utils.processing_utils import iterable_to_batc
 Tin = TypeVar("Tin")
 Tout = TypeVar("Tout")
 
-POISON_PILL = "<POISON_PILL>"
+
+class PoisonPill(str):  # noqa: SLOT000
+    pass
+
+
+POISON_PILL = PoisonPill("<POISON_PILL>")
 
 
 def process_with_threadpool_backpressure(
     process_batch_fun: Callable[[list[Tin]], Tout],
-    data: Iterable,
+    data: Iterable[Tin],
     max_workers: int = 1,
     batch_size: int = 1,
 ) -> Iterator[Tout]:
@@ -26,7 +31,7 @@ def process_with_threadpool_backpressure(
 
     with cf.ThreadPoolExecutor(max_workers=max_workers) as executor:
 
-        def gen_futures(num_new_jobs: int) -> Iterator[Future | str]:
+        def gen_futures(num_new_jobs: int) -> Iterator[Future[Tout] | PoisonPill]:
             for _ in range(num_new_jobs):
                 try:
                     next_job = next(it)
@@ -34,41 +39,48 @@ def process_with_threadpool_backpressure(
                 except StopIteration:  # noqa: PERF203
                     yield POISON_PILL
 
-        futures = list(gen_futures(max_workers))
+        futures = [f for f in gen_futures(max_workers) if not isinstance(f, PoisonPill)]
 
-        yield from _process_with_backpressure(gen_futures, futures)
+        yield from _process_with_backpressure(gen_futures, set(futures))
 
 
 def _process_with_backpressure(
-    gen_futures: Callable,
-    futures: list[Future | str],
+    gen_futures: Callable[[int], Iterator[Future[Tout] | PoisonPill]],
+    initial_futures: set[Future[Tout]],
 ) -> Iterator[Tout]:
-    def fill_compleded_by_new_jobs(
-        completed: list,
-        futures,  # noqa: ANN001
-    ) -> bool:
-        input_is_exhausted = False
-        for fu in gen_futures(len(completed)):
-            if fu != POISON_PILL:
-                futures.add(fu)
-            else:
-                input_is_exhausted = True
-                break
-        return input_is_exhausted
-
+    remaining_futures = initial_futures
     input_is_exhausted = False
     while not input_is_exhausted:
-        completed, futures = wait(futures, return_when=FIRST_COMPLETED)
+        completed, remaining_futures = wait(
+            remaining_futures,
+            return_when=FIRST_COMPLETED,
+        )
 
         input_is_exhausted = fill_compleded_by_new_jobs(
-            completed,
-            futures,
+            gen_futures,
+            num_completed=len(completed),
+            futures=remaining_futures,
         )
         yield from _yield_results(completed)
 
-    yield from _yield_results(completed=cf.as_completed(futures))
+    yield from _yield_results(completed=cf.as_completed(remaining_futures))
 
 
-def _yield_results(completed: Iterable[Future]) -> Iterator[Tout]:
+def fill_compleded_by_new_jobs(
+    gen_futures: Callable[[int], Iterator[Future[Tout] | PoisonPill]],
+    num_completed: int,
+    futures: set[Future[Tout]],
+) -> bool:
+    input_is_exhausted = False
+    for fu in gen_futures(num_completed):
+        if not isinstance(fu, PoisonPill):  # fu != POISON_PILL:
+            futures.add(fu)
+        else:
+            input_is_exhausted = True
+            break
+    return input_is_exhausted
+
+
+def _yield_results(completed: Iterable[Future[Tout]]) -> Iterator[Tout]:
     for fu in completed:
         yield fu.result()  # why a yield from? -> cause its processing batches!
